@@ -20,14 +20,12 @@
 
 #include "incidencedatetime.h"
 #include "ui_dialogdesktop.h"
+#include "incidenceeditor_debug.h"
 
 #include <CalendarSupport/KCalPrefs>
 
-#include <KCalCore/ICalTimeZones>
 #include <KCalUtils/IncidenceFormatter>
 
-#include "incidenceeditor_debug.h"
-#include <KSystemTimeZone>
 #include <QTimeZone>
 
 using namespace IncidenceEditorNG;
@@ -56,8 +54,8 @@ static bool incidenceHasDefaultTimes(const KCalCore::Incidence::Ptr &incidence)
             return true; // no duration to compare with
         }
 
-        const KDateTime start = incidence->dtStart();
-        const KDateTime end = incidence->dateTime(KCalCore::Incidence::RoleEnd);
+        const QDateTime start = incidence->dtStart();
+        const QDateTime end = incidence->dateTime(KCalCore::Incidence::RoleEnd);
         if (!end.isValid() || !start.isValid()) {
             return false;
         }
@@ -83,8 +81,8 @@ IncidenceDateTime::IncidenceDateTime(Ui::EventOrTodoDesktop *ui)
     mUi->mTimeZoneLabel->setContextMenuPolicy(Qt::NoContextMenu);
 
     const QList<QLineEdit *> lineEdits {
-        mUi->mStartDateEdit->lineEdit(), mUi->mEndDateEdit->lineEdit()
-                ,mUi->mStartTimeEdit->lineEdit(), mUi->mEndTimeEdit->lineEdit()};
+        mUi->mStartDateEdit->lineEdit(), mUi->mEndDateEdit->lineEdit(),
+                             mUi->mStartTimeEdit->lineEdit(), mUi->mEndTimeEdit->lineEdit()};
     for (QLineEdit *lineEdit : lineEdits) {
         if (lineEdit) {
             lineEdit->setClearButtonEnabled(false);
@@ -168,11 +166,11 @@ void IncidenceDateTime::load(const KCalCore::Incidence::Ptr &incidence)
     enableTimeEdits();
 
     if (mUi->mTimeZoneComboStart->currentIndex() == 0) {   // Floating
-        mInitialStartDT.setTimeSpec(mInitialStartDT.toLocalZone().timeSpec());
+        mInitialStartDT.setTimeZone(QTimeZone::systemTimeZone());
     }
 
     if (mUi->mTimeZoneComboEnd->currentIndex() == 0) {   // Floating
-        mInitialEndDT.setTimeSpec(mInitialEndDT.toLocalZone().timeSpec());
+        mInitialEndDT.setTimeZone(QTimeZone::systemTimeZone());
     }
 
     mWasDirty = false;
@@ -241,11 +239,11 @@ QTime IncidenceDateTime::endTime() const
 void IncidenceDateTime::setTimeZonesVisibility(bool visible)
 {
     static const QString tz(i18nc("@action show or hide the time zone widgets", "Time zones"));
-    QString placeholder(QStringLiteral("<a href=\"hide\"><font color='blue'>&lt;&lt; %1</font></a>"));
+    QString placeholder(QStringLiteral("<a href=\"hide\">&lt;&lt; %1</a>"));
     if (visible) {
         placeholder = placeholder.arg(tz);
     } else {
-        placeholder = QStringLiteral("<a href=\"show\"><font color='blue'>%1 &gt;&gt;</font></a>");
+        placeholder = QStringLiteral("<a href=\"show\">%1 &gt;&gt;</a>");
         placeholder = placeholder.arg(tz);
     }
     mUi->mTimeZoneLabel->setText(placeholder);
@@ -265,7 +263,7 @@ void IncidenceDateTime::updateStartTime(const QTime &newTime)
         return;
     }
 
-    KDateTime endDateTime = currentEndDateTime();
+    QDateTime endDateTime = currentEndDateTime();
     const int secsep = mCurrentStartDateTime.secsTo(endDateTime);
     mCurrentStartDateTime.setTime(newTime);
     if (mUi->mEndCheck->isChecked()) {
@@ -289,7 +287,7 @@ void IncidenceDateTime::updateStartDate(const QDate &newDate)
     const bool dateChanged = mCurrentStartDateTime.date().day() != newDate.day()
                              || mCurrentStartDateTime.date().month() != newDate.month();
 
-    KDateTime endDateTime = currentEndDateTime();
+    QDateTime endDateTime = currentEndDateTime();
     int daysep = mCurrentStartDateTime.daysTo(endDateTime);
     mCurrentStartDateTime.setDate(newDate);
     if (mUi->mEndCheck->isChecked()) {
@@ -311,11 +309,11 @@ void IncidenceDateTime::updateStartSpec()
     const QDate prevDate = mCurrentStartDateTime.date();
 
     if (mUi->mEndCheck->isChecked()
-        && currentEndDateTime().timeSpec() == mCurrentStartDateTime.timeSpec()) {
-        mUi->mTimeZoneComboEnd->selectTimeSpec(mUi->mTimeZoneComboStart->selectedTimeSpec());
+        && currentEndDateTime().timeZone() == mCurrentStartDateTime.timeZone()) {
+        mUi->mTimeZoneComboEnd->selectTimeZone(mUi->mTimeZoneComboStart->selectedTimeZone());
     }
 
-    mCurrentStartDateTime.setTimeSpec(mUi->mTimeZoneComboStart->selectedTimeSpec());
+    mCurrentStartDateTime.setTimeZone(mUi->mTimeZoneComboStart->selectedTimeZone());
 
     const bool dateChanged = mCurrentStartDateTime.date().day() != prevDate.day()
                              || mCurrentStartDateTime.date().month() != prevDate.month();
@@ -381,12 +379,12 @@ void IncidenceDateTime::enableEndEdit(bool enable)
     checkDirtyStatus();
 }
 
-bool IncidenceDateTime::timeZonesAreLocal(const KDateTime &start, const KDateTime &end)
+bool IncidenceDateTime::timeZonesAreLocal(const QDateTime &start, const QDateTime &end)
 {
     // Returns false if the incidence start or end timezone is not the local zone.
 
-    if ((start.isValid() && !start.timeSpec().isLocalZone())
-        || (end.isValid() && !end.timeSpec().isLocalZone())) {
+    if ((start.isValid() && start.timeZone() != QTimeZone::systemTimeZone())
+        || (end.isValid() && end.timeZone() != QTimeZone::systemTimeZone())) {
         return false;
     } else {
         return true;
@@ -403,12 +401,12 @@ void IncidenceDateTime::enableTimeEdits()
     if (mUi->mStartCheck->isChecked()) {
         mUi->mStartTimeEdit->setEnabled(!wholeDayChecked);
         mUi->mTimeZoneComboStart->setEnabled(!wholeDayChecked);
-        mUi->mTimeZoneComboStart->setFloating(wholeDayChecked, mInitialStartDT.timeSpec());
+        mUi->mTimeZoneComboStart->setFloating(wholeDayChecked, mInitialStartDT.timeZone());
     }
     if (mUi->mEndCheck->isChecked()) {
         mUi->mEndTimeEdit->setEnabled(!wholeDayChecked);
         mUi->mTimeZoneComboEnd->setEnabled(!wholeDayChecked);
-        mUi->mTimeZoneComboEnd->setFloating(wholeDayChecked, mInitialEndDT.timeSpec());
+        mUi->mTimeZoneComboEnd->setFloating(wholeDayChecked, mInitialEndDT.timeZone());
     }
 
     /**
@@ -454,7 +452,7 @@ bool IncidenceDateTime::isDirty(const KCalCore::Todo::Ptr &todo) const
     }
 
     if (mUi->mStartCheck->isChecked()) {
-        // Use mActiveStartTime. This is the KDateTime::Spec selected on load coming from
+        // Use mActiveStartTime. This is the QTimeZone selected on load coming from
         // the combobox. We use this one as it can slightly differ (e.g. missing
         // country code in the incidence time spec) from the incidence.
         if (currentStartDateTime() != mInitialStartDT) {
@@ -495,8 +493,8 @@ bool IncidenceDateTime::isDirty(const KCalCore::Event::Ptr &event) const
     } else {
         if (currentStartDateTime() != mInitialStartDT
             || currentEndDateTime() != mInitialEndDT
-            || currentStartDateTime().timeSpec() != mInitialStartDT.timeSpec()
-            || currentEndDateTime().timeSpec() != mInitialEndDT.timeSpec()) {
+            || currentStartDateTime().timeZone() != mInitialStartDT.timeZone()
+            || currentEndDateTime().timeZone() != mInitialEndDT.timeZone()) {
             return true;
         }
     }
@@ -525,24 +523,23 @@ bool IncidenceDateTime::isDirty(const KCalCore::Journal::Ptr &journal) const
 
 /// Private methods
 
-KDateTime IncidenceDateTime::currentStartDateTime() const
+QDateTime IncidenceDateTime::currentStartDateTime() const
 {
-    return KDateTime(
+    return QDateTime(
         mUi->mStartDateEdit->date(),
         mUi->mStartTimeEdit->time(),
-        mUi->mTimeZoneComboStart->selectedTimeSpec());
+        mUi->mTimeZoneComboStart->selectedTimeZone());
 }
 
-KDateTime IncidenceDateTime::currentEndDateTime() const
+QDateTime IncidenceDateTime::currentEndDateTime() const
 {
-    return KDateTime(
+    return QDateTime(
         mUi->mEndDateEdit->date(),
         mUi->mEndTimeEdit->time(),
-        mUi->mTimeZoneComboEnd->selectedTimeSpec());
+        mUi->mTimeZoneComboEnd->selectedTimeZone());
 }
 
-void IncidenceDateTime::load(const KCalCore::Event::Ptr &event, bool isTemplate,
-                             bool templateOverridesTimes)
+void IncidenceDateTime::load(const KCalCore::Event::Ptr &event, bool isTemplate, bool templateOverridesTimes)
 {
     // First en/disable the necessary ui bits and pieces
     mUi->mStartCheck->setVisible(false);
@@ -592,8 +589,8 @@ void IncidenceDateTime::load(const KCalCore::Event::Ptr &event, bool isTemplate,
             setTimes(event->dtStart(), event->dtEnd());
         }
     } else {
-        KDateTime startDT = event->dtStart();
-        KDateTime endDT = event->dtEnd();
+        QDateTime startDT = event->dtStart();
+        QDateTime endDT = event->dtEnd();
         setDateTimes(startDT, endDT);
     }
 
@@ -607,8 +604,7 @@ void IncidenceDateTime::load(const KCalCore::Event::Ptr &event, bool isTemplate,
     }
 }
 
-void IncidenceDateTime::load(const KCalCore::Journal::Ptr &journal, bool isTemplate,
-                             bool templateOverridesTimes)
+void IncidenceDateTime::load(const KCalCore::Journal::Ptr &journal, bool isTemplate, bool templateOverridesTimes)
 {
     // First en/disable the necessary ui bits and pieces
     mUi->mStartCheck->setVisible(false);
@@ -639,21 +635,20 @@ void IncidenceDateTime::load(const KCalCore::Journal::Ptr &journal, bool isTempl
     if (isTemplate) {
         if (templateOverridesTimes) {
             // We only use the template times if the user didn't override them.
-            setTimes(journal->dtStart(), KDateTime());
+            setTimes(journal->dtStart(), QDateTime());
         }
     } else {
-        KDateTime startDT = journal->dtStart();
+        QDateTime startDT = journal->dtStart();
 
         // Convert UTC to local timezone, if needed (i.e. for kolab #204059)
-        if (startDT.isUtc()) {
-            startDT = startDT.toLocalZone();
+        if (startDT.timeZone() == QTimeZone::utc()) {
+            startDT = startDT.toLocalTime();
         }
-        setDateTimes(startDT, KDateTime());
+        setDateTimes(startDT, QDateTime());
     }
 }
 
-void IncidenceDateTime::load(const KCalCore::Todo::Ptr &todo, bool isTemplate,
-                             bool templateOverridesTimes)
+void IncidenceDateTime::load(const KCalCore::Todo::Ptr &todo, bool isTemplate, bool templateOverridesTimes)
 {
     // First en/disable the necessary ui bits and pieces
     mUi->mStartCheck->setVisible(true);
@@ -707,7 +702,7 @@ void IncidenceDateTime::load(const KCalCore::Todo::Ptr &todo, bool isTemplate,
             this,
             &IncidenceDateTime::checkDirtyStatus);
 
-    const KDateTime rightNow = KDateTime(QDate::currentDate(), QTime::currentTime()).toLocalZone();
+    const QDateTime rightNow = QDateTime::currentDateTime();
 
     if (isTemplate) {
         if (templateOverridesTimes) {
@@ -715,8 +710,8 @@ void IncidenceDateTime::load(const KCalCore::Todo::Ptr &todo, bool isTemplate,
             setTimes(todo->dtStart(), todo->dateTime(KCalCore::Incidence::RoleEnd));
         }
     } else {
-        const KDateTime endDT = todo->hasDueDate() ? todo->dtDue(true /** first */) : rightNow;
-        const KDateTime startDT
+        const QDateTime endDT = todo->hasDueDate() ? todo->dtDue(true /** first */) : rightNow;
+        const QDateTime startDT
             = todo->hasStartDate() ? todo->dtStart(true /** first */) : rightNow;
         setDateTimes(startDT, endDT);
     }
@@ -728,12 +723,11 @@ void IncidenceDateTime::save(const KCalCore::Event::Ptr &event)
         event->setAllDay(true);
 
         // TODO: need to change this.
-        KDateTime eventDTStart = currentStartDateTime();
-        eventDTStart.setDateOnly(true);
+        QDateTime eventDTStart = currentStartDateTime();
+        event->setAllDay(true);
         event->setDtStart(eventDTStart);
 
-        KDateTime eventDTEnd = currentEndDateTime();
-        eventDTEnd.setDateOnly(true);
+        QDateTime eventDTEnd = currentEndDateTime();
 
         event->setDtEnd(eventDTEnd);
     } else { // Timed Event
@@ -763,7 +757,7 @@ void IncidenceDateTime::save(const KCalCore::Todo::Ptr &todo)
             todo->setDtRecurrence(currentStartDateTime());
         }
     } else {
-        todo->setDtStart(KDateTime());
+        todo->setDtStart(QDateTime());
     }
 
     if (mUi->mEndCheck->isChecked()) {
@@ -771,7 +765,7 @@ void IncidenceDateTime::save(const KCalCore::Todo::Ptr &todo)
         // Set allday must be executed after setDtDue
         todo->setAllDay(mUi->mWholeDayCheck->isChecked());
     } else {
-        todo->setDtDue(KDateTime());
+        todo->setDtDue(QDateTime());
     }
 }
 
@@ -780,8 +774,8 @@ void IncidenceDateTime::save(const KCalCore::Journal::Ptr &journal)
     journal->setAllDay(mUi->mWholeDayCheck->isChecked());
 
     if (mUi->mWholeDayCheck->isChecked()) {   // All day journal
-        KDateTime journalDTStart = currentStartDateTime();
-        journalDTStart.setDateOnly(true);
+        QDateTime journalDTStart = currentStartDateTime();
+        journal->setAllDay(true);
         journal->setDtStart(journalDTStart);
     } else { // Timed Journal
         // set date/time end
@@ -789,49 +783,28 @@ void IncidenceDateTime::save(const KCalCore::Journal::Ptr &journal)
     }
 }
 
-void IncidenceDateTime::setDateTimes(const KDateTime &start, const KDateTime &end)
+void IncidenceDateTime::setDateTimes(const QDateTime &start, const QDateTime &end)
 {
-    const KDateTime::Spec startSpec = start.timeSpec();
-    const KDateTime::Spec endSpec = end.timeSpec();
-
-    // Combo boxes only have system time zones
-    if (startSpec.type() == KDateTime::TimeZone) {
-        const auto systemTz = QTimeZone(startSpec.timeZone().name().toUtf8());
-        if (!systemTz.isValid()) {
-            mTimeZones.push_back(startSpec.timeZone().name().toUtf8());
-        }
-    }
-
-    if (endSpec.type() == KDateTime::TimeZone) {
-        const auto systemTz = QTimeZone(endSpec.timeZone().name().toUtf8());
-        if (!systemTz.isValid()) {
-            mTimeZones.push_back(endSpec.timeZone().name().toUtf8());
-        }
-    }
-
-    mUi->mTimeZoneComboStart->setAdditionalTimeZones(mTimeZones);
-    mUi->mTimeZoneComboEnd->setAdditionalTimeZones(mTimeZones);
-
     if (start.isValid()) {
         mUi->mStartDateEdit->setDate(start.date());
         mUi->mStartTimeEdit->setTime(start.time());
-        mUi->mTimeZoneComboStart->selectTimeSpec(start.timeSpec());
+        mUi->mTimeZoneComboStart->selectTimeZone(start.timeZone());
     } else {
-        KDateTime dt(QDate::currentDate(), QTime::currentTime());
+        QDateTime dt = QDateTime::currentDateTime();
         mUi->mStartDateEdit->setDate(dt.date());
         mUi->mStartTimeEdit->setTime(dt.time());
-        mUi->mTimeZoneComboStart->selectTimeSpec(dt.timeSpec());
+        mUi->mTimeZoneComboStart->selectTimeZone(dt.timeZone());
     }
 
     if (end.isValid()) {
         mUi->mEndDateEdit->setDate(end.date());
         mUi->mEndTimeEdit->setTime(end.time());
-        mUi->mTimeZoneComboEnd->selectTimeSpec(end.timeSpec());
+        mUi->mTimeZoneComboEnd->selectTimeZone(end.timeZone());
     } else {
-        KDateTime dt(QDate::currentDate(), QTime::currentTime().addSecs(60 * 60));
+        QDateTime dt(QDate::currentDate(), QTime::currentTime().addSecs(60 * 60));
         mUi->mEndDateEdit->setDate(dt.date());
         mUi->mEndTimeEdit->setTime(dt.time());
-        mUi->mTimeZoneComboEnd->selectTimeSpec(dt.timeSpec());
+        mUi->mTimeZoneComboEnd->selectTimeZone(dt.timeZone());
     }
 
     mCurrentStartDateTime = currentStartDateTime();
@@ -851,8 +824,7 @@ void IncidenceDateTime::updateStartToolTips()
             = KCalUtils::IncidenceFormatter::dateTimeToString(
             currentStartDateTime(),
             mUi->mWholeDayCheck->isChecked(),
-            false,
-            KSystemTimeZones::local());
+            false);
         mUi->mStartDateEdit->setToolTip(i18n("Starts: %1", datetimeStr));
         mUi->mStartTimeEdit->setToolTip(i18n("Starts: %1", datetimeStr));
     } else {
@@ -868,8 +840,7 @@ void IncidenceDateTime::updateEndToolTips()
             = KCalUtils::IncidenceFormatter::dateTimeToString(
             currentEndDateTime(),
             mUi->mWholeDayCheck->isChecked(),
-            false,
-            KSystemTimeZones::local());
+            false);
         if (mLoadedIncidence->type() == KCalCore::Incidence::TypeTodo) {
             mUi->mEndDateEdit->setToolTip(i18n("Due on: %1", datetimeStr));
             mUi->mEndTimeEdit->setToolTip(i18n("Due on: %1", datetimeStr));
@@ -888,7 +859,7 @@ void IncidenceDateTime::updateEndToolTips()
     }
 }
 
-void IncidenceDateTime::setTimes(const KDateTime &start, const KDateTime &end)
+void IncidenceDateTime::setTimes(const QDateTime &start, const QDateTime &end)
 {
     // like setDateTimes(), but it set only the start/end time, not the date
     // it is used while applying a template to an event.
@@ -898,8 +869,8 @@ void IncidenceDateTime::setTimes(const KDateTime &start, const KDateTime &end)
 
     mUi->mEndTimeEdit->setTime(end.time());
 
-    mUi->mTimeZoneComboStart->selectTimeSpec(start.timeSpec());
-    mUi->mTimeZoneComboEnd->selectTimeSpec(end.timeSpec());
+    mUi->mTimeZoneComboStart->selectTimeZone(start.timeZone());
+    mUi->mTimeZoneComboEnd->selectTimeZone(end.timeZone());
 
 //   emitDateTimeStr();
 }
@@ -929,13 +900,15 @@ bool IncidenceDateTime::endDateTimeEnabled() const
 bool IncidenceDateTime::isValid() const
 {
     if (startDateTimeEnabled() && !currentStartDateTime().isValid()) {
-        //TODO: Add strings
+        mLastErrorString = i18nc("@info",
+                                 "Invalid start date and time.");
         qCWarning(INCIDENCEEDITOR_LOG) << "Start date is invalid";
         return false;
     }
 
     if (endDateTimeEnabled() && !currentEndDateTime().isValid()) {
-        //TODO: Add strings
+        mLastErrorString = i18nc("@info",
+                                 "Invalid end date and time.");
         qCWarning(INCIDENCEEDITOR_LOG) << "End date is invalid";
         return false;
     }
@@ -962,13 +935,6 @@ bool IncidenceDateTime::isValid() const
     }
 }
 
-static QString timespecToString(const KDateTime::Spec &spec)
-{
-    QString str = QLatin1String("type=") + QString::number(spec.type()) + QLatin1String(
-        "; timezone=") + spec.timeZone().name();
-    return str;
-}
-
 void IncidenceDateTime::printDebugInfo() const
 {
     qCDebug(INCIDENCEEDITOR_LOG) << "startDateTimeEnabled()          : " << startDateTimeEnabled();
@@ -990,14 +956,10 @@ void IncidenceDateTime::printDebugInfo() const
     qCDebug(INCIDENCEEDITOR_LOG) << "mInitialEndDT                   : "
                                  << mInitialEndDT.toString();
 
-    qCDebug(INCIDENCEEDITOR_LOG) << "currentStartDateTime().timeSpec(): " << timespecToString(
-        currentStartDateTime().timeSpec());
-    qCDebug(INCIDENCEEDITOR_LOG) << "currentEndDateTime().timeSpec()  : " << timespecToString(
-        currentStartDateTime().timeSpec());
-    qCDebug(INCIDENCEEDITOR_LOG) << "mInitialStartDT.timeSpec()       : " << timespecToString(
-        mInitialStartDT.timeSpec());
-    qCDebug(INCIDENCEEDITOR_LOG) << "mInitialEndDT.timeSpec()         : " << timespecToString(
-        mInitialEndDT.timeSpec());
+    qCDebug(INCIDENCEEDITOR_LOG) << "currentStartDateTime().timeZone(): " << currentStartDateTime().timeZone().id();
+    qCDebug(INCIDENCEEDITOR_LOG) << "currentEndDateTime().timeZone()  : " << currentEndDateTime().timeZone().id();
+    qCDebug(INCIDENCEEDITOR_LOG) << "mInitialStartDT.timeZone()       : " << mInitialStartDT.timeZone().id();
+    qCDebug(INCIDENCEEDITOR_LOG) << "mInitialEndDT.timeZone()         : " << mInitialEndDT.timeZone().id();
 
     qCDebug(INCIDENCEEDITOR_LOG) << "dirty test1: "
                                  << (mLoadedIncidence->allDay()
@@ -1022,11 +984,9 @@ void IncidenceDateTime::printDebugInfo() const
         qCDebug(INCIDENCEEDITOR_LOG) << "dirty test4.2: "
                                      << (currentEndDateTime() != mInitialEndDT);
         qCDebug(INCIDENCEEDITOR_LOG) << "dirty test4.3: "
-                                     << (currentStartDateTime().timeSpec()
-            != mInitialStartDT.timeSpec());
+                                     << (currentStartDateTime().timeZone() != mInitialStartDT.timeZone());
         qCDebug(INCIDENCEEDITOR_LOG) << "dirty test4.4: "
-                                     << (currentEndDateTime().timeSpec()
-            != mInitialEndDT.timeSpec());
+                                     << (currentEndDateTime().timeZone() != mInitialEndDT.timeZone());
     }
 }
 
